@@ -9,7 +9,10 @@ class ColumnarFrame:
         self.data = {}
         if data is not None:
             for k, v in data.items():
-                self._check_length(v)
+                if isinstance(v, Column):
+                    v = v.to_list()
+                if isinstance(v, list):
+                    self._check_length(v)
                 self.data[k] = Column(v, self.rows)
 
     def _check_length(self, v):
@@ -28,6 +31,8 @@ class ColumnarFrame:
         return self.data[name]
 
     def __setitem__(self, name, value):
+        if isinstance(value, Column):
+            value = value.to_list()
         if isinstance(value, list):
             self._check_length(value)
         self.data[name] = Column(value, self.rows)
@@ -46,15 +51,16 @@ class ColumnarFrame:
 
     def to_csv(
             self, name, *, encoding='utf-8',
-            sep=',', na_rep='', index=False, header=True):
+            sep=',', na_rep='', index=False, header=True,
+            quoting=csv.QUOTE_MINIMAL):
         if isinstance(name, str):
             with open(name, 'w', encoding=encoding) as f:
-                self._write_csv(f, sep, na_rep, index, header)
+                self._write_csv(f, sep, na_rep, index, header, quoting)
         else:
-            self._write_csv(name, sep, na_rep, index, header)
+            self._write_csv(name, sep, na_rep, index, header, quoting)
 
-    def _write_csv(self, stream, sep, na_rep, _, header):
-        w = csv.writer(stream, delimiter=sep)
+    def _write_csv(self, stream, sep, na_rep, _, header, quoting):
+        w = csv.writer(stream, delimiter=sep, quoting=quoting)
         if na_rep != '':
             iters = [
                 map(
@@ -67,3 +73,25 @@ class ColumnarFrame:
         if header:
             w.writerow(list(self.data.keys()))
         w.writerows(zip(*iters))
+
+    def assign(self, **kwargs):
+        ncf = ColumnarFrame(self.data)
+        for k, v in kwargs.items():
+            ncf[k] = v
+        return ncf
+
+    def __iter__(self):
+        data = iter([
+            {k: v for k, v in zip(self.data.keys(), c)}
+            for c in zip(*self.data.values())
+        ])
+        return data
+
+    def remove(self, func):
+        data = {k: [] for k in self.data.keys()}
+        for c in zip(*self.data.values()):
+            row = {k: v for k, v in zip(self.data.keys(), c)}
+            if not func(row):
+                for k, v in row.items():
+                    data[k].append(v)
+        return ColumnarFrame(data)
